//
// This code is part of https://developer.mescius.com/document-solutions/dot-net-imaging-api/demos.
// Copyright (c) MESCIUS inc. All rights reserved.
//
using System;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using System.Linq;
using System.Numerics;
using GrapeCity.Documents.Drawing;
using GrapeCity.Documents.Text;
using GrapeCity.Documents.Imaging;
using GCTEXT = GrapeCity.Documents.Text;
using GCDRAW = GrapeCity.Documents.Drawing;

namespace DsImagingWeb.Demos
{
    // This sample demonstrates how to use GrayscaleBitmap.AutoContrast()
    // to automatically adjust the contrast of a black and white image.
    public class AutoContrast
    {
        public GcBitmap GenerateImage(Size pixelSize, float dpi, bool opaque, string[] sampleParams = null)
        {
            opaque = true;
            var bmp = new GcBitmap(pixelSize.Width, pixelSize.Height, opaque, dpi, dpi);
            using (var origBmp = new GcBitmap())
            {
                // Load a sample photo:
                var imagePath = Path.Combine("Resources", "ImagesBis", "tremblant.png");
                GrayscaleBitmap grayBmp;
                using (var stm = new FileStream(imagePath, FileMode.Open, FileAccess.Read, FileShare.Read, 4096, FileOptions.RandomAccess))
                {
                    origBmp.Load(stm);
                    origBmp.Opaque = opaque;
                    grayBmp = origBmp.ToGrayscaleBitmap();
                }

                // Resize the original photo to fit two versions on the resulting bitmap:
                int w = pixelSize.Width;
                int h = pixelSize.Height / 2;
                using (var sizedBmp = origBmp.Resize(w, h, InterpolationMode.Cubic))
                {
                    // Copy the resized original into the upper half of the resulting bitmap:
                    bmp.BitBlt(sizedBmp, 0, 0);
                    // Auto adjust the contrast of the original image and copy the result into the lower half:
                    grayBmp.AutoContrast();
                    using (var tbmp = grayBmp.ToGcBitmap())
                        bmp.BitBlt(tbmp, 0, h);
                }

                // Add captions (original and adjusted images):
                var lineh = 2;
                using (var g = bmp.CreateGraphics(null))
                {
                    var foreColor = Color.Yellow;
                    var backColor = Color.Blue;
                    var font = GCTEXT.Font.FromFile(Path.Combine("Resources", "Fonts", "cour.ttf"));
                    g.DrawLine(0, h, w * 2, h, new GCDRAW.Pen(Color.Gray, lineh * 2));
                    var tf = new TextFormat() { Font = font, FontSize = 18, ForeColor = foreColor, BackColor = backColor, FontBold = true };
                    var th = g.MeasureString("QWERTY", tf).Height;
                    g.DrawString(" Original image ", tf, new PointF(0, h - th + lineh));
                    g.DrawString(" Auto contrast applied ", tf, new PointF(0, h * 2 + lineh - th + lineh));
                }
            }
            return bmp;
        }
    }
}
